@@ -342,7 +342,8 @@ class Api:
         extra_headers: Optional[Dict[str, any]] = None,
         extra_cookies: Optional[Dict[str, str]] = None,
         allow_redirects: Optional[bool] = None,
-        debug: Optional[bool] = None
+        debug: Optional[bool] = None,
+        max_concurent_processes: Optional[int] = None
     ) -> List[bool]:
         return self._request.download_async(
             urls_paths,
@@ -353,7 +354,8 @@ class Api:
             sleep_s_between_failed_requests=sleep_s_between_failed_requests,
             extra_headers=extra_headers,
             extra_cookies=extra_cookies,
-            debug=debug
+            debug=debug,
+            max_concurent_processes=max_concurent_processes
         )
 
     @classmethod
@@ -367,7 +369,8 @@ class Api:
         extra_headers: Optional[Dict[str, any]] = None,
         extra_cookies: Optional[Dict[str, str]] = None,
         allow_redirects: bool = True,
-        debug: Optional[bool] = None
+        debug: Optional[bool] = None,
+        max_concurent_processes: Optional[int] = None
     ) -> List[bool]:
         return Api(default_headers=cls.default_headers(), extra_headers=cls.extra_headers()).download_async(
             urls_paths,
@@ -379,7 +382,8 @@ class Api:
             extra_headers=extra_headers,
             extra_cookies=extra_cookies,
             allow_redirects=allow_redirects,
-            debug=debug
+            debug=debug,
+            max_concurent_processes=max_concurent_processes
         )
 
 
